@@ -39,6 +39,7 @@ THE SOFTWARE.
 #include <poll.h>
 #include <errno.h>
 #include <assert.h>
+#include <stdint.h>
 
 #include <gnutls/x509.h>
 
@@ -1063,6 +1064,7 @@ WaitressReturn_t WaitressFetchCall (WaitressHandle_t *waith) {
 
 	/* initialize */
 	memset (&waith->request, 0, sizeof (waith->request));
+	waith->request.sockfd = -1;
 	waith->request.dataHandler = WaitressHandleIdentity;
 	waith->request.read = WaitressOrdinaryRead;
 	waith->request.write = WaitressOrdinaryWrite;
@@ -1104,7 +1106,9 @@ WaitressReturn_t WaitressFetchCall (WaitressHandle_t *waith) {
 		gnutls_deinit (waith->request.tlsSession);
 		gnutls_certificate_free_credentials (waith->tlsCred);
 	}
-	close (waith->request.sockfd);
+	if (waith->request.sockfd != -1) {
+		close (waith->request.sockfd);
+	}
 	free (waith->request.buf);
 
 	if (wRet == WAITRESS_RET_OK &&
