@@ -103,7 +103,8 @@ static void BarMainGetLoginCredentials (BarSettings_t *settings,
 		char passBuf[100];
 		BarUiMsg (settings, MSG_QUESTION, "Password: ");
 		BarReadlineStr (passBuf, sizeof (passBuf), input, BAR_RL_NOECHO);
-		write (STDIN_FILENO, "\n", 1);
+		/* write missing newline */
+		puts ("");
 		settings->password = strdup (passBuf);
 	}
 }
@@ -136,7 +137,8 @@ static void BarMainGetInitialStation (BarApp_t *app) {
 	}
 	/* no autostart? ask the user */
 	if (app->curStation == NULL) {
-		app->curStation = BarUiSelectStation (app, app->ph.stations, "Select station: ", NULL);
+		app->curStation = BarUiSelectStation (app, app->ph.stations,
+				"Select station: ", NULL, app->settings.autoselect);
 	}
 	if (app->curStation != NULL) {
 		BarUiPrintStation (&app->settings, app->curStation);
@@ -291,22 +293,19 @@ static void BarMainLoop (BarApp_t *app) {
 
 		/* check whether player finished playing and start playing new
 		 * song */
-		if (app->player.mode >= PLAYER_FINISHED_PLAYBACK ||
-				app->player.mode == PLAYER_FREED) {
-			if (app->curStation != NULL) {
-				/* what's next? */
-				if (app->playlist != NULL) {
-					PianoSong_t *histsong = app->playlist;
-					app->playlist = app->playlist->next;
-					BarUiHistoryPrepend (app, histsong);
-				}
-				if (app->playlist == NULL) {
-					BarMainGetPlaylist (app);
-				}
-				/* song ready to play */
-				if (app->playlist != NULL) {
-					BarMainStartPlayback (app, &playerThread);
-				}
+		if (app->player.mode == PLAYER_FREED && app->curStation != NULL) {
+			/* what's next? */
+			if (app->playlist != NULL) {
+				PianoSong_t *histsong = app->playlist;
+				app->playlist = app->playlist->next;
+				BarUiHistoryPrepend (app, histsong);
+			}
+			if (app->playlist == NULL) {
+				BarMainGetPlaylist (app);
+			}
+			/* song ready to play */
+			if (app->playlist != NULL) {
+				BarMainStartPlayback (app, &playerThread);
 			}
 		}
 
@@ -339,11 +338,13 @@ int main (int argc, char **argv) {
 	/* init some things */
 	ao_initialize ();
 	gnutls_global_init ();
-	PianoInit (&app.ph);
 
 	BarSettingsInit (&app.settings);
 	BarSettingsRead (&app.settings);
 
+	PianoInit (&app.ph, app.settings.partnerUser, app.settings.partnerPassword,
+			app.settings.device, app.settings.inkey, app.settings.outkey);
+
 	BarUiMsg (&app.settings, MSG_NONE,
 			"Welcome to " PACKAGE " (" VERSION ")! ");
 	if (app.settings.keys[BAR_KS_HELP] == BAR_KS_DISABLED) {
@@ -356,7 +357,6 @@ int main (int argc, char **argv) {
 
 	WaitressInit (&app.waith);
 	app.waith.url.host = strdup (PIANO_RPC_HOST);
-	app.waith.url.tls = true;
 	app.waith.tlsFingerprint = app.settings.tlsFingerprint;
 
 	/* init fds */
@@ -368,9 +368,19 @@ int main (int argc, char **argv) {
 	assert (sizeof (app.input.fds) / sizeof (*app.input.fds) >= 2);
 	app.input.fds[1] = open (app.settings.fifo, O_RDWR);
 	if (app.input.fds[1] != -1) {
-		FD_SET(app.input.fds[1], &app.input.set);
-		BarUiMsg (&app.settings, MSG_INFO, "Control fifo at %s opened\n",
-				app.settings.fifo);
+		struct stat s;
+
+		/* check for file type, must be fifo */
+		fstat (app.input.fds[1], &s);
+		if (!S_ISFIFO (s.st_mode)) {
+			BarUiMsg (&app.settings, MSG_ERR, "File at %s is not a fifo\n", app.settings.fifo);
+			close (app.input.fds[1]);
+			app.input.fds[1] = -1;
+		} else {
+			FD_SET(app.input.fds[1], &app.input.set);
+			BarUiMsg (&app.settings, MSG_INFO, "Control fifo at %s opened\n",
+					app.settings.fifo);
+		}
 	}
 	app.input.maxfd = app.input.fds[0] > app.input.fds[1] ? app.input.fds[0] :
 			app.input.fds[1];
