@@ -24,6 +24,8 @@ THE SOFTWARE.
 #ifndef _UI_H
 #define _UI_H
 
+#include <stdbool.h>
+
 #include <piano.h>
 #include <waitress.h>
 
@@ -37,11 +39,11 @@ typedef void (*BarUiSelectStationCallback_t) (BarApp_t *app, char *buf);
 
 void BarUiMsg (const BarSettings_t *, const BarUiMsg_t, const char *, ...);
 PianoStation_t *BarUiSelectStation (BarApp_t *, PianoStation_t *, const char *,
-		BarUiSelectStationCallback_t);
+		BarUiSelectStationCallback_t, bool);
 PianoSong_t *BarUiSelectSong (const BarSettings_t *, PianoSong_t *,
 		BarReadlineFds_t *);
 PianoArtist_t *BarUiSelectArtist (BarApp_t *, PianoArtist_t *);
-char *BarUiSelectMusicId (BarApp_t *, PianoStation_t *, PianoSong_t *, const char *);
+char *BarUiSelectMusicId (BarApp_t *, PianoStation_t *, const char *);
 void BarStationFromGenre (BarApp_t *);
 void BarUiPrintStation (const BarSettings_t *, PianoStation_t *);
 void BarUiPrintSong (const BarSettings_t *, const PianoSong_t *, 
