@@ -1,5 +1,5 @@
 /*
-Copyright (c) 2008-2011
+Copyright (c) 2008-2012
 	Lars-Dominik Braun <lars@6xq.net>
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -50,6 +50,8 @@ static inline void BarUiDoSkipSong (struct audioPlayer *player) {
 	assert (player != NULL);
 
 	player->doQuit = 1;
+	/* unlocking an unlocked mutex is forbidden by some implementations */
+	pthread_mutex_trylock (&player->pauseMutex);
 	pthread_mutex_unlock (&player->pauseMutex);
 }
 
@@ -99,7 +101,7 @@ BarUiActCallback(BarUiActAddMusic) {
 	assert (selStation != NULL);
 
 	reqData.musicId = BarUiSelectMusicId (app, selStation,
-			selSong, "Add artist or title to station: ");
+			"Add artist or title to station: ");
 	if (reqData.musicId != NULL) {
 		if (!BarTransformIfShared (app, selStation)) {
 			return;
@@ -147,7 +149,7 @@ BarUiActCallback(BarUiActCreateStation) {
 	WaitressReturn_t wRet;
 	PianoRequestDataCreateStation_t reqData;
 
-	reqData.id = BarUiSelectMusicId (app, NULL, NULL,
+	reqData.id = BarUiSelectMusicId (app, NULL,
 			"Create station from artist or title: ");
 	if (reqData.id != NULL) {
 		reqData.type = "mi";
@@ -259,8 +261,7 @@ BarUiActCallback(BarUiActDebug) {
 			"rating:\t%i\n"
 			"stationId:\t%s\n"
 			"title:\t%s\n"
-			"trackToken:\t%s\n"
-			"userSeed:\t%s\n",
+			"trackToken:\t%s\n",
 			selSong->album,
 			selSong->artist,
 			selSong->audioFormat,
@@ -272,8 +273,7 @@ BarUiActCallback(BarUiActDebug) {
 			selSong->rating,
 			selSong->stationId,
 			selSong->title,
-			selSong->trackToken,
-			selSong->userSeed);
+			selSong->trackToken);
 }
 
 /*	rate current song
@@ -316,7 +316,7 @@ BarUiActCallback(BarUiActMoveSong) {
 	reqData.step = 0;
 
 	reqData.to = BarUiSelectStation (app, app->ph.stations,
-			"Move song to station: ", NULL);
+			"Move song to station: ", NULL, false);
 	if (reqData.to != NULL) {
 		/* find original station (just is case we're playing a quickmix
 		 * station) */
@@ -379,7 +379,7 @@ BarUiActCallback(BarUiActRenameStation) {
  */
 BarUiActCallback(BarUiActSelectStation) {
 	PianoStation_t *newStation = BarUiSelectStation (app, app->ph.stations,
-			"Select station: ", NULL);
+			"Select station: ", NULL, app->settings.autoselect);
 	if (newStation != NULL) {
 		app->curStation = newStation;
 		BarUiPrintStation (&app->settings, app->curStation);
@@ -475,7 +475,7 @@ BarUiActCallback(BarUiActSelectQuickMix) {
 		PianoStation_t *toggleStation;
 		while ((toggleStation = BarUiSelectStation (app, app->ph.stations,
 				"Toggle quickmix for station: ",
-				BarUiActQuickmixCallback)) != NULL) {
+				BarUiActQuickmixCallback, false)) != NULL) {
 			toggleStation->useQuickMix = !toggleStation->useQuickMix;
 		}
 		BarUiMsg (&app->settings, MSG_INFO, "Setting quickmix stations... ");
@@ -660,7 +660,8 @@ BarUiActCallback(BarUiActManageStation) {
 			}
 		} else if (selectBuf[0] == 't') {
 			PianoStation_t *station = BarUiSelectStation (app,
-					reqData.info.stationSeeds, "Delete seed station: ", NULL);
+					reqData.info.stationSeeds, "Delete seed station: ", NULL,
+					false);
 			if (station != NULL) {
 				PianoRequestDataDeleteSeed_t subReqData;
 
